@@ -4,11 +4,12 @@ use warnings;
 use strict;
 use Carp;
 
-use version; our $VERSION = qv('1.0.1');    # update POD & Changes & README
+use version; our $VERSION = qv('1.0.2');    # update POD & Changes & README
 
 # update DEPENDENCIES in POD & Makefile.PL & README
 use IO::Stream::const;
 use MIME::Base64;
+use Scalar::Util qw( weaken );
 
 use constant HTTP_OK => 200;
 
@@ -79,6 +80,7 @@ sub EVENT {
                 }
                 $m->EVENT($e);
                 $self->{_slave}->{_master} = $m;
+                weaken($self->{_slave}->{_master});
                 $m->{_slave} = $self->{_slave};
                 if ($self->{_want_write}) {
                     $self->{_slave}->WRITE();
@@ -103,7 +105,7 @@ IO::Stream::Proxy::HTTPS - HTTPS proxy plugin for IO::Stream
 
 =head1 VERSION
 
-This document describes IO::Stream::Proxy::HTTPS version 1.0.1
+This document describes IO::Stream::Proxy::HTTPS version 1.0.2
 
 
 =head1 SYNOPSIS
